@@ -4,6 +4,6 @@
 #include<RcppArmadillo.h>
 // [[Rcpp::depends(RcppArmadillo)]]
 
-arma::vec QRWMR(arma::mat& x, arma::vec& y, arma::vec b);
+arma::vec QRWMR(const arma::mat& x, const arma::vec& y, arma::vec b);
 
 #endif
